@@ -885,6 +885,19 @@ class ContainerPackageBuilder(LinuxFhsBasedPackageBuilder):
         # to the local registry.
         buildx_builder_name = "agent_image_buildx_builder"
 
+        # print docker and buildx version
+        docker_version_output = (
+            common.check_output_with_log(["docker", "version"]).decode().strip()
+        )
+        logging.info(f"Using docker version:\n{docker_version_output}\n")
+
+        buildx_version_output = (
+            common.check_output_with_log(["docker", "buildx", "version"])
+            .decode()
+            .strip()
+        )
+        logging.info(f"Using buildx version {buildx_version_output}")
+
         # check if builder already exists.
         ls_output = (
             common.check_output_with_log(["docker", "buildx", "ls"]).decode().strip()
@@ -967,7 +980,7 @@ class ContainerPackageBuilder(LinuxFhsBasedPackageBuilder):
             "--build-arg",
             f"BUILDER_NAME={self.name}",
             "--build-arg",
-            f"BASE_IMAGE=localhost:5000/{base_image_name}",
+            f"BASE_IMAGE=localhost:5005/{base_image_name}",
             "--build-arg",
             f"BASE_IMAGE_SUFFIX={base_image_tag_suffix}",
         ]
@@ -1012,7 +1025,7 @@ class ContainerPackageBuilder(LinuxFhsBasedPackageBuilder):
         # Create container with local image registry. And mount existing registry root with base images.
         registry_container = build_in_docker.LocalRegistryContainer(
             name="agent_image_output_registry",
-            registry_port=5000,
+            registry_port=5005,
             registry_data_path=registry_data_path,
         )
 
